searchData={"items":[{"type":"module","title":"CsvGenerator","doc":"This library provides an easy way to generate CSV files.\nIt allows you to define the colums and their respective types.","ref":"CsvGenerator.html"},{"type":"module","title":"Example - CsvGenerator","doc":"defmodule MyCSV do\n      use CsvGenerator\n\n      column :name, :string\n      column :joined, :date, format: \"%d-%m-%Y\"\n      column :points, :integer, label: \"points earned\"\n      hardcoded :string, \"Game\", \"domino\"\n    end\n\nYou would then render the CSV bij calling the `render/1` method with\nthe list of lines to render.","ref":"CsvGenerator.html#module-example"},{"type":"module","title":"Example - CsvGenerator","doc":"iex> MyCSV.render([ \n       %{ name: \"Chris McCord\", joined: ~D[2020-01-01], points: 110},\n       %{ name: \"Jose Valim\", joined: ~D[2020-03-29], points: 10} ])\n    \"\\\"name\\\",\\\"joined\\\",\\\"points earned\\\",\\\"Game\\\"\\n\\\"Chris McCord\\\",01-01-2020,110,\\\"domino\\\"\\n\\\"Jose Valim\\\",29-03-2020,10,\\\"domino\\\"\"\n\nBy default the CSV columns will be seperated by a `\",\"`, the lines by a `\"\\n\"`.\nThis can be changed by using `delimiter` and `line_ending`.","ref":"CsvGenerator.html#module-example"},{"type":"module","title":"Example - CsvGenerator","doc":"defmodule MyCSV do\n      use CsvGenerator\n\n      delimiter \";\"\n      line_ending \"\\r\\n\"\n\n      column :name, :string\n      column :birthday, :date, format: \"%d-%m-%Y\"\n      column :points, :integer\n    end\n\n    iex> MyCSV.render([ \n       %{ name: \"Jose Valim\", joined: ~D[2020-03-29], points: 10} ])\n    \"\\\"name\\\";\\\"joined\\\";\\\"points earned\\\"\\n\\\"Jose Valim\\\";29-03-2020;10\"\n\n# Formatting\n\nA formatter is included, to be able to have `mix format` use it, you have to add it to your own `.formatter.exs` in `import_deps`.","ref":"CsvGenerator.html#module-example"},{"type":"module","title":"Example - CsvGenerator","doc":"[\n      import_deps: [:ecto, :phoenix, :csv_generator],\n      inputs: [\"*.{ex,exs}\", \"priv/*/seeds.exs\", \"{config,lib,test}/**/*.{ex,exs}\"],\n      subdirectories: [\"priv/*/migrations\"]\n    ]","ref":"CsvGenerator.html#module-example"},{"type":"macro","title":"CsvGenerator.column/3","doc":"Defines a column in the CSV.\n\n`column name, type, options`\n\nThe column name will be used to select the value from the given input.\n\nThe following types are currently supported:\n\nType         | Elixir type             | Default format\n:----------- | :---------------------- | :------------------\n`:string`    | `String`                | n/a\n`:integer`   | `Integer`               | n/a\n`:float`     | `Float`                 | n/a\n`:date`      | `Date`                  | `\"%Y-%m-%d\"`\n`:time`      | `DateTime` or `Integer` | `\"%H:%M\"`\n`:datetime`  | `DateTime`              | `\"%Y-%m-%d %H:%M:%S\"`\n\nFor `:date`, `:time`, and `:datetime`, any of the Date(Time) types that\nare compatible with `Calendar.Strftime.strftime/2` are allowed.\n`:time` also allows an `Integer` value that represents the time within a day.","ref":"CsvGenerator.html#column/3"},{"type":"macro","title":"Options - CsvGenerator.column/3","doc":"* `:header` - Use this instead of the name for column header.\n\n  * `:format` - Supply a different format string, see https://hexdocs.pm/calendar/readme.html.\n\n  * `:digits` - Supply the number of digits for a `Float`.\n\n  * `:with`   - Specifies a function to be called on the value before processing.\n                column :value, :integer, with: &calc/1 or\n                column :value, :integer, with: fn(x) -> x * 2 end\n  * `:source` - Use another field as the source for this column, this allows you to use the same column multiple times.","ref":"CsvGenerator.html#column/3-options"},{"type":"macro","title":"nil values - CsvGenerator.column/3","doc":"Columns with a `nil` value will be empty in the output.\nIf you do not want this, if you want some _default_ value, then use the `with:` option to supply a function that transforms the `nil` into something, formatting and rounding options will be applied.\n    column :c3po, :integer, with: fn i -> if i == nil, do: 0, else: i end","ref":"CsvGenerator.html#column/3-nil-values"},{"type":"macro","title":"CsvGenerator.decimal_point/1","doc":"Specify the decimal point, default: \".\"","ref":"CsvGenerator.html#decimal_point/1"},{"type":"macro","title":"Example - CsvGenerator.decimal_point/1","doc":"decimal_point \",\"","ref":"CsvGenerator.html#decimal_point/1-example"},{"type":"macro","title":"CsvGenerator.delimiter/1","doc":"Specify the character to use as column delimiter, default: \",\"","ref":"CsvGenerator.html#delimiter/1"},{"type":"macro","title":"Example - CsvGenerator.delimiter/1","doc":"delimiter \";\"","ref":"CsvGenerator.html#delimiter/1-example"},{"type":"macro","title":"CsvGenerator.hardcoded/3","doc":"Defines a column in the CSV that will always have the same hardcoded value.","ref":"CsvGenerator.html#hardcoded/3"},{"type":"macro","title":"Example - CsvGenerator.hardcoded/3","doc":"hardcoded :string, \"name\", \"John\"\n\nFor `type` check out the possibilities in `column/3`.\nMake sure the `value` is of `type`.","ref":"CsvGenerator.html#hardcoded/3-example"},{"type":"macro","title":"CsvGenerator.header/1","doc":"Add the header to the generated CSV, default: true.","ref":"CsvGenerator.html#header/1"},{"type":"macro","title":"Example - CsvGenerator.header/1","doc":"header false","ref":"CsvGenerator.html#header/1-example"},{"type":"macro","title":"CsvGenerator.line_ending/1","doc":"Specify the line ending to use, default: \"\\n\".","ref":"CsvGenerator.html#line_ending/1"},{"type":"macro","title":"Example - CsvGenerator.line_ending/1","doc":"line_ending \"\\r\\n\"","ref":"CsvGenerator.html#line_ending/1-example"},{"type":"module","title":"Example","doc":"To generate the CSV output you call `render` on your module with your data.","ref":"Example.html"},{"type":"function","title":"Example.render/1","doc":"Called to render the CSV output.","ref":"Example.html#render/1"},{"type":"function","title":"Example - Example.render/1","doc":"iex> MyCSV.render(list)\n   \"...\"","ref":"Example.html#render/1-example"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}